==> hindent-6.1.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              6.1.0
visibility:           public
id:                   hindent-6.1.0-A5dBvL5dO305mbvIywt2Mu
key:                  hindent-6.1.0-A5dBvL5dO305mbvIywt2Mu
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  9e1e2f61136798babd569c31ff006e00
exposed:              True
exposed-modules:      HIndent
hidden-modules:
    HIndent.Applicative HIndent.ByteString HIndent.CabalFile
    HIndent.CodeBlock HIndent.CommandlineOptions HIndent.Config
    HIndent.Error HIndent.Fixity HIndent.GhcLibParserWrapper.GHC.Hs
    HIndent.Language HIndent.LanguageExtension
    HIndent.LanguageExtension.Conversion
    HIndent.LanguageExtension.Types HIndent.ModulePreprocessing
    HIndent.ModulePreprocessing.CommentRelocation HIndent.Parse
    HIndent.Path.Find HIndent.Pragma HIndent.Pretty
    HIndent.Pretty.Combinators HIndent.Pretty.Combinators.Comment
    HIndent.Pretty.Combinators.Getter HIndent.Pretty.Combinators.Indent
    HIndent.Pretty.Combinators.Lineup HIndent.Pretty.Combinators.Op
    HIndent.Pretty.Combinators.Outputable
    HIndent.Pretty.Combinators.RhsSeparator
    HIndent.Pretty.Combinators.String HIndent.Pretty.Combinators.Switch
    HIndent.Pretty.Combinators.Wrap HIndent.Pretty.Import
    HIndent.Pretty.Import.Sort HIndent.Pretty.NodeComments
    HIndent.Pretty.Pragma HIndent.Pretty.SigBindFamily
    HIndent.Pretty.Types HIndent.Printer Paths_hindent

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-A5dBvL5dO305mbvIywt2Mu
depends:
    Cabal-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-9.6.6 ghc-lib-parser-ex-9.6.0.2-Bitwd42PUGaBm2BMf2d3nC
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-5nnJ4FeW1ct8RzxtI8AAka
    path-0.9.5-DfruEJJ8tcfBnmUf5K9kU4
    path-io-1.8.2-JrqPlMNC1aq8uS4K7MHLsS
    regex-tdfa-1.3.2.5-HbcBjlVCDu1Hxg2xP0HSjv
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp
    transformers-0.6.1.0 unicode-show-0.1.1.1-63OXcxXFzu93t35nLCNHil
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    yaml-0.11.11.2-2uKQ3imTBzRK4XVeM4BHFd

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-hindent-z-hindent-internal
version:              6.1.0
package-name:         hindent
lib-name:             hindent-internal
id:                   hindent-6.1.0-51XDThhfSH24RZU9JzdeQa-hindent-internal
key:                  hindent-6.1.0-51XDThhfSH24RZU9JzdeQa-hindent-internal
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  5f7b0503a562e771730e06edf3e50b04
exposed-modules:      HIndent.Internal.Test.Markdone
hidden-modules:       Paths_hindent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-51XDThhfSH24RZU9JzdeQa-hindent-internal
depends:
    Cabal-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-lib-parser-ex-9.6.0.2-Bitwd42PUGaBm2BMf2d3nC
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-5nnJ4FeW1ct8RzxtI8AAka
    path-0.9.5-DfruEJJ8tcfBnmUf5K9kU4
    path-io-1.8.2-JrqPlMNC1aq8uS4K7MHLsS
    regex-tdfa-1.3.2.5-HbcBjlVCDu1Hxg2xP0HSjv
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp
    transformers-0.6.1.0 unicode-show-0.1.1.1-63OXcxXFzu93t35nLCNHil
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    yaml-0.11.11.2-2uKQ3imTBzRK4XVeM4BHFd

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-6.1.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-hindent-z-hindent-internal
version:              6.1.0
package-name:         hindent
lib-name:             hindent-internal
id:                   hindent-6.1.0-EhidRo5WIQ58GIoZ7gn5WF-hindent-internal
key:                  hindent-6.1.0-EhidRo5WIQ58GIoZ7gn5WF-hindent-internal
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  c7f0ba76cfa88112b575e39daf1396d6
exposed-modules:      HIndent.Internal.Test.Markdone
hidden-modules:       Paths_hindent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-EhidRo5WIQ58GIoZ7gn5WF-hindent-internal
depends:
    Cabal-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-lib-parser-ex-9.6.0.2-1CrafzddWDi1NnRUpuNJcq
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-3S7fKkQk1IxEovxwORLzkN
    path-0.9.5-6Ohlzf1XDfBHYD7cHvk9od
    path-io-1.8.2-6M5DvYUxwBtIAYrhl5kUol
    regex-tdfa-1.3.2.5-qZoXOptISAJcpXFSPLOTl
    split-0.2.5-LIo01L9HFTI75RwsLzYVkn syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt
    transformers-0.6.1.0 unicode-show-0.1.1.1-7FDnLldBwmJHvdRheaJItz
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    yaml-0.11.11.2-CS9jj0skP8B8obc9v5e4bH

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              6.1.0
visibility:           public
id:                   hindent-6.1.0-B0fXna2RFa45U1CFv7NrzL
key:                  hindent-6.1.0-B0fXna2RFa45U1CFv7NrzL
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  4f936a76458c09058f8be0fbd71751c0
exposed:              True
exposed-modules:      HIndent
hidden-modules:
    HIndent.Applicative HIndent.ByteString HIndent.CabalFile
    HIndent.CodeBlock HIndent.CommandlineOptions HIndent.Config
    HIndent.Error HIndent.Fixity HIndent.GhcLibParserWrapper.GHC.Hs
    HIndent.Language HIndent.LanguageExtension
    HIndent.LanguageExtension.Conversion
    HIndent.LanguageExtension.Types HIndent.ModulePreprocessing
    HIndent.ModulePreprocessing.CommentRelocation HIndent.Parse
    HIndent.Path.Find HIndent.Pragma HIndent.Pretty
    HIndent.Pretty.Combinators HIndent.Pretty.Combinators.Comment
    HIndent.Pretty.Combinators.Getter HIndent.Pretty.Combinators.Indent
    HIndent.Pretty.Combinators.Lineup HIndent.Pretty.Combinators.Op
    HIndent.Pretty.Combinators.Outputable
    HIndent.Pretty.Combinators.RhsSeparator
    HIndent.Pretty.Combinators.String HIndent.Pretty.Combinators.Switch
    HIndent.Pretty.Combinators.Wrap HIndent.Pretty.Import
    HIndent.Pretty.Import.Sort HIndent.Pretty.NodeComments
    HIndent.Pretty.Pragma HIndent.Pretty.SigBindFamily
    HIndent.Pretty.Types HIndent.Printer Paths_hindent

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-B0fXna2RFa45U1CFv7NrzL
depends:
    Cabal-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-9.6.6 ghc-lib-parser-ex-9.6.0.2-1CrafzddWDi1NnRUpuNJcq
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-3S7fKkQk1IxEovxwORLzkN
    path-0.9.5-6Ohlzf1XDfBHYD7cHvk9od
    path-io-1.8.2-6M5DvYUxwBtIAYrhl5kUol
    regex-tdfa-1.3.2.5-qZoXOptISAJcpXFSPLOTl
    split-0.2.5-LIo01L9HFTI75RwsLzYVkn syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt
    transformers-0.6.1.0 unicode-show-0.1.1.1-7FDnLldBwmJHvdRheaJItz
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    yaml-0.11.11.2-CS9jj0skP8B8obc9v5e4bH

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
